@@ -301,6 +301,14 @@ impl Initial {
         let rpc = RpcClient::create(bus, handlers, opts);
         Ok(Arc::new(rpc))
     }
+    pub async fn init_bus_client(&self) -> EResult<elbus::ipc::Client> {
+        let bus = tokio::time::timeout(
+            self.bus_timeout(),
+            elbus::ipc::Client::connect(&self.elbus_config()?),
+        )
+        .await??;
+        Ok(bus)
+    }
     #[inline]
     pub fn init_registry(&self, rpc: &Arc<RpcClient>) -> Registry {
         Registry {
